@@ -862,7 +862,7 @@ panel_applet_expose (GtkWidget      *widget,
 	height = widget->allocation.height - 2 * border_width;
 
 	gtk_paint_focus (widget->style, widget->window,
-			 GTK_WIDGET_STATE (widget),
+			 gtk_widget_get_state (widget),
 			 &event->area, widget, "panel_applet",
 			 x, y, width, height);
 
