@@ -2,6 +2,7 @@
  * panel-action-button.h: panel "Action Button" module
  *
  * Copyright (C) 2002 Sun Microsystems, Inc.
+ * Copyright (C) 2004 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,7 +26,7 @@
 #ifndef __PANEL_ACTION_BUTTON_H__
 #define __PANEL_ACTION_BUTTON_H__
 
-#include <gtk/gtkbutton.h>
+#include <gtk/gtk.h>
 #include "button-widget.h"
 #include "panel-widget.h"
 #include "panel-enums.h"
@@ -86,11 +87,12 @@ gboolean   panel_action_button_load_from_drag   (PanelToplevel          *topleve
 						 const char             *drag_string,
 						 int                    *old_applet_idx);
 
-void       panel_action_lock_screen (GtkWidget *widget);
-void       panel_action_logout      (GtkWidget *widget);
-void       panel_action_run_program (GtkWidget *widget);
-void       panel_action_search      (GtkWidget *widget);
-void       panel_action_screenshot  (GtkWidget *widget);
+gboolean             panel_action_get_is_disabled (PanelActionButtonType type);
+GCallback            panel_action_get_invoke      (PanelActionButtonType type);
+G_CONST_RETURN char *panel_action_get_icon_name   (PanelActionButtonType type);
+G_CONST_RETURN char *panel_action_get_text        (PanelActionButtonType type);
+G_CONST_RETURN char *panel_action_get_tooltip     (PanelActionButtonType type);
+G_CONST_RETURN char *panel_action_get_drag_id     (PanelActionButtonType type);
 
 G_END_DECLS
 
